@@ -97,7 +97,12 @@ def _get_system_lshw_dict():
     :return: A python dict from the lshw json output
     """
     out, _e = utils.execute('lshw', '-quiet', '-json', log_stdout=False)
-    return json.loads(out)
+    out = json.loads(out)
+    # Depending on lshw version, output might be a list, starting with
+    # https://github.com/lyonel/lshw/commit/135a853c60582b14c5b67e5cd988a8062d9896f4  # noqa
+    if isinstance(out, list):
+        return out[0]
+    return out
 
 
 def _udev_settle():
@@ -277,6 +282,10 @@ def is_md_device(raid_device):
         utils.execute('mdadm', '--detail', raid_device)
         LOG.debug("%s is an md device", raid_device)
         return True
+    except FileNotFoundError:
+        LOG.debug('mdadm has not been found, assuming %s is not an md device',
+                  raid_device)
+        return False
     except processutils.ProcessExecutionError:
         LOG.debug("%s is not an md device", raid_device)
         return False
@@ -328,6 +337,9 @@ def _md_scan_and_assemble():
     """
     try:
         utils.execute('mdadm', '--assemble', '--scan', '--verbose')
+    except FileNotFoundError:
+        LOG.warning('mdadm has not been found, RAID devices will not be '
+                    'supported')
     except processutils.ProcessExecutionError:
         LOG.info('No new RAID devices assembled during start-up')
 
@@ -1111,8 +1123,6 @@ class GenericHardwareManager(HardwareManager):
             LOG.warning('Could not get real physical RAM from lshw: %s', e)
             physical = None
         else:
-            if isinstance(sys_dict, str):
-                sys_dict = json.loads(sys_dict)
             physical = _calc_memory(sys_dict)
 
             if not physical:
